@@ -147,7 +147,12 @@ class AutoPackage(object):
             url = ""
             if "source" in spec_dict and "git" in spec_dict["source"]:
                 url = spec_dict["source"]["git"]
-            header_content = self.podspecTool.podspecForPushHeaderRepo(podName, version, url)
+            if self.arguments.isflutter:
+                self.podspecTool.changePodspecForPushRepo()
+                podspec_name = podName + ".podspec"
+                header_content = self.fileHandle.readFile(podspec_name)
+            else:
+                header_content = self.podspecTool.podspecForPushHeaderRepo(podName, version, url)
             for repo_url in header_repo_list:
                 self.cocoapodsTool.push_header_repo(podName, version, header_content, repo_url, projectPath)
             self.podspecTool.changePodspecForPushRepo()
