@@ -98,7 +98,7 @@ class Package(object):
         self.shell.excommand_until_done("mkdir -p combineDir/deviceApp")
         self.shell.excommand_until_done("mkdir -p combineDir/simulatorApp")
         self.shell.excommand_until_done("rm -rf ios/Flutter/App.framework ios/Flutter/Flutter.framework")
-        self.shell.excommand_until_done("cd ios; pod install --verbose || { pod repo update --verbose; }")
+        self.shell.excommand_until_done("cd ios; pod update --verbose")
         if debug:
             flavercmd = ""
             build_device_path = "build/ios/Debug-iphoneos"
